=============
django-setman
=============

Django settings manager. Another.

Requirements
============

* `Python <http://www.python.org/>`_ 2.6 or higher
* `Django <http://www.djangoproject.com/>`_ 1.3 or higher

Installation
============

*On most UNIX-like systems, you'll probably need to run these commands as root
or using sudo.*

To install use::

    $ pip install django-setman

Or::

    $ python setup.py install

Also, you can retrieve fresh version of ``setman`` from `GitHub
<https://github.com/odeskps/django-setman>`_::

    $ git clone git://github.com/odeskps/django-setman.git

and place ``setman`` directory somewhere to ``PYTHONPATH`` (or ``sys.path``).

License
=======

``django-setman`` is licensed under the `BSD License
<https://github.com/odeskps/django-setman/blob/master/LICENSE>`_.

Usage. More information
=======================

See full documentation at ``docs/`` directory.

Bugs, feature requests?
=======================

If you found some bug in ``setman`` reusable app, please, add new issue to the
project's `GitHub issues <https://github.com/odeskps/django-setman/issues>`_.
